@@ -198,7 +198,7 @@ SEXP trlan_svd(SEXP A, SEXP ne, SEXP opts,
   kmax = imin2(kmax, m+1);
 
   /* Tolerance */
-  getScalarListElement(tol, opts, "tol", asReal, sqrt(DOUBLE_EPS));
+  getScalarListElement(tol, opts, "tol", asReal, sqrt(DBL_EPSILON));
 
   /* Maximum number of matrix-vector products */
   getScalarListElement(maxiter, opts, "maxiter", asInteger, neig*m);
@@ -327,7 +327,7 @@ SEXP trlan_eigen(SEXP A, SEXP ne, SEXP opts,
   kmax = imin2(kmax, m+1);
 
   /* Tolerance */
-  getScalarListElement(tol, opts, "tol", asReal, sqrt(DOUBLE_EPS));
+  getScalarListElement(tol, opts, "tol", asReal, sqrt(DBL_EPSILON));
 
   /* Maximum number of matrix-vector products */
   getScalarListElement(maxiter, opts, "maxiter", asInteger, neig*m);
